/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#include "shared.h"

/*-------------------------------------------------------------------------*/

/* Runtime config data */
rc_data_t rc_data;

/* Global widgets */
GtkWidget
  *main_window = NULL,
  *popup_menu  = NULL;

GtkBuilder
  *main_window_builder = NULL,
  *popup_menu_builder  = NULL;

/* QSO data record */
qso_record_t qso_record;

/* File desc of external log-file to be imported */
FILE *ext_log_fp = NULL;

/*-------------------------------------------------------------------------*/

